@@ -203,11 +203,13 @@ class Repository(object):
 
     svn_get='checkout'
     easy_install_path = ["easy_install"]
+    easy_install_flag = '-q'
+    pip_path = ["pip"]
     python = "python"
     svn = "svn"
     dev = []
 
-    def __init__(self, name, root=None, trunk=None, stable=None, release=None, tag=None, pyname=None, pypi=None, dev=False, username=None, install=True, rev=None, local=None):
+    def __init__(self, name, root=None, trunk=None, stable=None, release=None, tag=None, pyname=None, pypi=None, dev=False, username=None, install=True, rev=None, local=None, platform=None):
         class _TEMP_(object): pass
         self.config = _TEMP_()
         self.config.name=name
@@ -219,6 +221,7 @@ class Repository(object):
         self.config.pyname=pyname
         self.config.pypi=pypi
         self.config.local=local
+        self.config.platform=platform
         if dev == 'True' or dev is True:
             self.config.dev=True
         else:
@@ -244,6 +247,11 @@ class Repository(object):
         #
         self.pypi = config.pypi
         self.local = config.local
+        self.platform = config.platform
+        if config.platform is None:
+            self.platform_re = None
+        else:
+            self.platform_re = re.compile(config.platform)
         if not config.pypi is None:
             self.pyname=config.pypi
         else:
@@ -348,6 +356,8 @@ class Repository(object):
             print >>OUTPUT, 'rev=%s' % str(config.rev)
         if not config.username is None:
             print >>OUTPUT, 'username=%s' % str(config.username)
+        if not config.platform is None:
+            print >>OUTPUT, 'platform=%s' % config.platform
 
 
     def find_pkgroot(self, trunk=False, stable=False, release=False):
@@ -415,6 +425,8 @@ class Repository(object):
         self.perform_install(dir=dir, install=install, preinstall=preinstall, offline=offline)
         
     def perform_install(self, dir=None, install=True, preinstall=False, offline=False):
+        if not self.platform_re is None and not self.platform_re.match(sys.platform):
+            return
         if self.pkgdir is None and self.local is None:
             self.easy_install(install, preinstall, dir, offline)
             return
@@ -489,23 +501,40 @@ class Repository(object):
             self.run([self.python, 'setup.py', 'install'], dir=dir)
 
     def easy_install(self, install, preinstall, dir, offline):
+        #return self.pip_install(install, preinstall, dir, offline)
         try:
             if install:
                 if offline:
                     self.run([self.python, 'setup.py', 'install'], dir=dir)
                 else:
-                    self.run(self.easy_install_path + ['-q', self.pypi])
+                    self.run(self.easy_install_path + [Repository.easy_install_flag, self.pypi], dir=os.path.dirname(dir))
             elif preinstall: 
                 if not os.path.exists(dir):
-                    self.run(self.easy_install_path + ['-q', '--exclude-scripts', '--always-copy', '--editable', '--build-directory', '.', self.pypi], dir=os.path.dirname(dir))
+                    self.run(self.easy_install_path + [Repository.easy_install_flag, '--exclude-scripts', '--always-copy', '--editable', '--build-directory', '.', self.pypi], dir=os.path.dirname(dir))
         except OSError, err:
             print ""
             print "Error installing package %s with easy_install" % self.name
             print str(err)
             sys.exit(1)
 
+    def pip_install(self, install, preinstall, dir, offline):
+        try:
+            if install:
+                if offline:
+                    self.run([self.python, 'setup.py', 'install'], dir=dir)
+                else:
+                    self.run(self.pip_path + ['-v', self.pypi])
+            elif preinstall: 
+                if not os.path.exists(dir):
+                    self.run(self.pip_path + ['-v', '--no-install', '--download', '.', self.pypi], dir=os.path.dirname(dir))
+        except OSError, err:
+            print ""
+            print "Error installing package %s with pip" % self.name
+            print str(err)
+            sys.exit(1)
+
     def easy_upgrade(self):
-        self.run(self.easy_install_path + ['-q', '--upgrade', self.pypi])
+        self.run(self.easy_install_path + [Repository.easy_install_flag, '--upgrade', self.pypi])
 
     def run(self, cmd, dir=None):
         cwd=os.getcwd()
@@ -513,6 +542,7 @@ class Repository(object):
             os.chdir(dir)
             cwd=dir
         print "Running command '%s' in directory %s" % (" ".join(cmd), cwd)
+        sys.stdout.flush()
         call_subprocess(cmd, filter_stdout=filter_python_develop, show_stdout=True)
         if not dir is None:
             os.chdir(cwd)
@@ -726,6 +756,8 @@ class Installer(object):
             vpy_main.raise_exceptions=True
         #
         global logger
+        if options.verbose:
+            Repository.easy_install_flag = '-v'
         verbosity = options.verbose - options.quiet
         self.logger = Logger([(Logger.level_for_integer(2-verbosity), sys.stdout)])
         logger = self.logger
@@ -734,6 +766,7 @@ class Installer(object):
         #
         global using_subversion
         try:
+            sys.stdout.flush()
             call_subprocess(['svn'+executable_extension,'help'], show_stdout=False)
         except OSError, err:
             print ""
@@ -1015,14 +1048,18 @@ class Installer(object):
             bindir = join(self.abshome_dir,"bin")
         if is_jython:
             Repository.python = os.path.abspath(join(bindir, 'jython.bat'))
-        elif sys.platform.startswith('win'):
-            Repository.python = os.path.abspath(join(bindir, 'pythonw'))
+        #elif sys.platform.startswith('win'):
+            #Repository.python = os.path.abspath(join(bindir, 'python'))
         else:
             Repository.python = os.path.abspath(join(bindir, 'python'))
         if os.path.exists(os.path.abspath(join(bindir, 'easy_install'))):
             Repository.easy_install_path = [Repository.python, os.path.abspath(join(bindir, 'easy_install'))]
         else:
             Repository.easy_install_path = [os.path.abspath(join(bindir, 'easy_install.exe'))]
+        if os.path.exists(os.path.abspath(join(bindir, 'pip'))):
+            Repository.pip_path = [Repository.python, os.path.abspath(join(bindir, 'pip'))]
+        else:
+            Repository.pip_path = [os.path.abspath(join(bindir, 'pip.exe'))]
         #
         if options.preinstall or not options.offline:
             self.get_packages(options)
@@ -1114,6 +1151,7 @@ class Installer(object):
                     rmtree( join(self.abshome_dir,todir) )
                 cmd = [Repository.svn,Repository.svn_get,'-q',self.svnjoin(pkgroot,fromdir),join(self.abshome_dir,todir)]
             print "Running command '%s'" % " ".join(cmd)
+            sys.stdout.flush()
             call_subprocess(cmd, filter_stdout=filter_python_develop,show_stdout=True)
 
     def read_config_file(self, file=None, fp=None):
